==> dokuwiki-2012.10.13.tgz: dokuwiki/lib/plugins/plugin/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author VictorCastelan <victorcastelan@gmail.com>
 * @author Jordan Mero  hack.jord@gmail.com
 * @author Felipe Martinez <metalmartinez@gmail.com>
 * @author Javier Aranda <internet@javierav.com>
 * @author Zerial <fernando@zerial.org>
 * @author Marvin Ortega <maty1206@maryanlinux.com>
 * @author Daniel Castro Alvarado <dancas2@gmail.com>
 * @author Fernando J. Gómez <fjgomez@gmail.com>
 * @author Victor Castelan <victorcastelan@gmail.com>
 * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
 * @author emezeta <emezeta@infoprimo.com>
 * @author Oscar Ciudad <oscar@jacho.net>
 * @author Ruben Figols <ruben.figols@gmail.com>
 * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
 */
$lang['menu']                  = 'Administración de Plugins';
$lang['download']              = 'Descargar e instalar un nuevo plugin';
$lang['manage']                = 'Plugins instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'borrar';
$lang['btn_settings']          = 'configuraciones';
$lang['btn_download']          = 'Descargar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado:';
$lang['lastupdate']            = 'Última actualización:';
$lang['source']                = 'Origen:';
$lang['unknown']               = 'desconocido';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'El plugin %s ha sido actualizado con éxito';
$lang['updates']               = 'Los siguientes plugins han sido actualizados con éxito';
$lang['update_none']           = 'No se encontraron actualizaciones.';
$lang['deleting']              = 'Eliminando ...';
$lang['deleted']               = 'El plugin %s ha sido eliminado.';
$lang['downloading']           = 'Descargando ...';
$lang['downloaded']            = 'El plugin %s ha sido instalado con éxito';
$lang['downloads']             = 'Los siguientes plugins han sido instalados con éxito:';
$lang['download_none']         = 'No se han encontrado plugins, o hubo algún problema durante la descarga o la instalación.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin no devolvió información, puede ser inválido.';
$lang['name']                  = 'Nombre:';
$lang['date']                  = 'Fecha:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descripción:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ha ocurrido un error desconocido.';
$lang['error_download']        = 'Incapaz de descargar el archivo del plugin: %s';
$lang['error_badurl']          = 'Se sospecha que la URL es incorrecta - incapaz de determinar el nombre del archivo a partir de la URL.';
$lang['error_dircreate']       = 'Incapaz de crear el directorio temporal para la descarga';
$lang['error_decompress']      = 'El administrador de plugins fue incapaz de descomprimir el fichero descargado. Esto puede ser por una descarga errónea, en cuyo caso debieras intentar nuevamente; o el formato de compresión es desconocido, en este caso deberás descargar e instalar el plugin manualmente.';
$lang['error_copy']            = 'Hubo un error al copiar el fichero mientras se intentaban instalar ficheros para el plugin <em>%s</em>: el disco puede estar lleno o los permisos del fichero pueden ser incorrectos. Esto puede haber terminado con una instalación parcial del plugin y haber dejado la instalación del wiki en una situación inestable';
$lang['error_delete']          = 'Hubo un error al intentar eliminar el plugin <em>%s</em>. La causa más probable es que no se cuente con los permisos necesarios en el fichero o en el directorio';
$lang['enabled']               = 'Plugin %s habilitado.';
$lang['notenabled']            = 'Plugin %s no puede ser habilitado, verifica los permisos del archivo.';
$lang['disabled']              = 'Plugin %s desabilitado.';
$lang['notdisabled']           = 'Plugin %s no puede ser desabilitado, verifica los permisos de archivo.';
$lang['packageinstalled']      = 'Plugin (%d plugin(s): %s) instalado exitosamente.';

==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/plugin/lang/es/lang.php <==
<?php
/**
 * spanish language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Miguel Pagano <miguel.pagano@gmail.com>
 * @author Oscar M. Lage <r0sk10@gmail.com>
 * @author Gabriel Castillo <gch@pumas.ii.unam.mx>
 * @author oliver@samera.com.py
 * @author Enrico Nicoletto <liverig@gmail.com>
 * @author Manuel Meco <manuel.meco@gmail.com>
 * @author VictorCastelan <victorcastelan@gmail.com>
 * @author Jordan Mero  hack.jord@gmail.com
 * @author Felipe Martinez <metalmartinez@gmail.com>
 * @author Javier Aranda <internet@javierav.com>
 * @author Zerial <fernando@zerial.org>
 * @author Marvin Ortega <maty1206@maryanlinux.com>
 * @author Daniel Castro Alvarado <dancas2@gmail.com>
 * @author Fernando J. Gómez <fjgomez@gmail.com>
 * @author Victor Castelan <victorcastelan@gmail.com>
 * @author Mauro Javier Giamberardino <mgiamberardino@gmail.com>
 * @author emezeta <emezeta@infoprimo.com>
 * @author Oscar Ciudad <oscar@jacho.net>
 * @author Ruben Figols <ruben.figols@gmail.com>
 * @author Gerardo Zamudio <gerardo@gerardozamudio.net>
 * @author Mercè López mercelz@gmail.com
 */
$lang['menu']                  = 'Administración de Plugins';
$lang['download']              = 'Descargar e instalar un nuevo plugin';
$lang['manage']                = 'Plugins instalados';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizar';
$lang['btn_delete']            = 'borrar';
$lang['btn_settings']          = 'configuraciones';
$lang['btn_download']          = 'Descargar';
$lang['btn_enable']            = 'Guardar';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalado:';
$lang['lastupdate']            = 'Última actualización:';
$lang['source']                = 'Origen:';
$lang['unknown']               = 'desconocido';
$lang['updating']              = 'Actualizando ...';
$lang['updated']               = 'El plugin %s ha sido actualizado con éxito';
$lang['updates']               = 'Los siguientes plugins han sido actualizados con éxito';
$lang['update_none']           = 'No se encontraron actualizaciones.';
$lang['deleting']              = 'Eliminando ...';
$lang['deleted']               = 'El plugin %s ha sido eliminado.';
$lang['downloading']           = 'Descargando ...';
$lang['downloaded']            = 'El plugin %s ha sido instalado con éxito';
$lang['downloads']             = 'Los siguientes plugins han sido instalados con éxito:';
$lang['download_none']         = 'No se han encontrado plugins, o hubo algún problema durante la descarga o la instalación.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componentes';
$lang['noinfo']                = 'Este plugin no devolvió información, puede ser inválido.';
$lang['name']                  = 'Nombre:';
$lang['date']                  = 'Fecha:';
$lang['type']                  = 'Tipo:';
$lang['desc']                  = 'Descripción:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ha ocurrido un error desconocido.';
$lang['error_download']        = 'Incapaz de descargar el archivo del plugin: %s';
$lang['error_badurl']          = 'Se sospecha que la URL es incorrecta - incapaz de determinar el nombre del archivo a partir de la URL.';
$lang['error_dircreate']       = 'Incapaz de crear el directorio temporal para la descarga';
$lang['error_decompress']      = 'El administrador de plugins fue incapaz de descomprimir el fichero descargado. Esto puede ser por una descarga errónea, en cuyo caso debieras intentar nuevamente; o el formato de compresión es desconocido, en este caso deberás descargar e instalar el plugin manualmente.';
$lang['error_copy']            = 'Hubo un error al copiar el fichero mientras se intentaban instalar ficheros para el plugin <em>%s</em>: el disco puede estar lleno o los permisos del fichero pueden ser incorrectos. Esto puede haber terminado con una instalación parcial del plugin y haber dejado la instalación del wiki en una situación inestable';
$lang['error_delete']          = 'Hubo un error al intentar eliminar el plugin <em>%s</em>. La causa más probable es que no se cuente con los permisos necesarios en el fichero o en el directorio';
$lang['enabled']               = 'Plugin %s habilitado.';
$lang['notenabled']            = 'Plugin %s no puede ser habilitado, verifica los permisos del archivo.';
$lang['disabled']              = 'Plugin %s deshabilitado.';
$lang['notdisabled']           = 'Plugin %s no puede ser deshabilitado, verifica los permisos de archivo.';
$lang['packageinstalled']      = 'Plugin (%d plugin(s): %s) instalado exitosamente.';
